OC.L10N.register(
    "settings",
    {
    "Private" : "პირადი",
    "Local" : "ლოკალური",
    "Federated" : "ფედერალური",
    "Verify" : "დამოწმება",
    "Verifying …" : "მოწმდება …",
    "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
    "Very weak password" : "ძალიან სუსტი პაროლი",
    "Weak password" : "სუსტი პაროლი",
    "So-so password" : "ნორმალური პაროლი",
    "Good password" : "კარგი პაროლი",
    "Strong password" : "ძლიერი პაროლ",
    "Groups" : "ჯგუფები",
    "{actor} changed your password" : "{actor} მომხმარებელმა შეცვალა თქვენი პაროლი",
    "You changed your password" : "თქვენ შეცვალეთ თქვენი პაროლი",
    "Your password was reset by an administrator" : "თქვენი პაროლი ადმინისტრატორმა აღადგინა",
    "{actor} changed your email address" : "{actor} მომხმარებელმა შეცვალა თქვენი ელ-ფოსტის მისამართი",
    "You changed your email address" : "თქვენ შეცვალეთ თქვენი ელ-ფოსტის მისამართი",
    "Your email address was changed by an administrator" : "თქვენი ელ-ფოსტის მისამართი ადმინისტრატორის მიერ შეიცვალა",
    "Security" : "უსაფრთხოება",
    "You successfully logged in using two-factor authentication (%1$s)" : "თქვენ ორ-ფაქტორიანი აუტენტიფიკაციით წარმატებით გაიარეთ ავტორიზაცია (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "ავტორიზაცია ორ-ფაქტორიანი აუტენტიფიკაციით ვერ მოხერხდა (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>თქვენი პაროლი</strong> ან <strong>ელ-ფოსტის მისამართი</strong> შეიცვალა",
    "Wrong password" : "არასწორი პაროლი",
    "Saved" : "დამახსოვრდა",
    "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
    "Authentication error" : "აუტენტიფიკაციის შეცდომა",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
    "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
    "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
    "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
    "Email setting test" : "ელ-ფოსტის დაყენების შემოწმება",
    "Well done, %s!" : "ყველაფერი კარგადაა, %s!",
    "If you received this email, the email configuration seems to be correct." : "იმ შემთხვევაში თუ მიიღეთ ეს ელ-წერილი, ელ-ფოსტის კონფიგურაცია კარგად უნდა იყოს.",
    "Email could not be sent. Check your mail server log" : "ელ-წერილი ვერ იგზავნება. გთხოვთ შეამოწმოთ მეილ-სერვერის ლოგი",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ელ-წერილის გაგზავნისას წარმოიშვა შეცდომა. გთხოვთ გადახედოთ თქვენს პარამეტრებს. (შეცდომა: %s)",
    "Invalid user" : "არასწორი მომხმარებელი",
    "Invalid mail address" : "არასწორი საფოსტო მისამართი",
    "Settings saved" : "პარამეტრები შენახულია",
    "Unable to change full name" : "სრული სახელის ცვლილება ვერ ხერხდება",
    "Unable to change email address" : "ელ-ფოსტის მისამართი ვერ იცვლება",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "თქვენი Twitter-ის ანგარიშის დასამოწმებლად, Twitter-ზე დაპოსტეთ შემდეგი (მიაქციათ ყურადღება რომ პოსტავთ ხაზის წყვეტის გარეშე): ",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "თქვენი საიტის დასამოწმებლად, შემდეგი მოცულობა მოათავსეთ web-root-ში '.well-known/CloudIdVerificationCode.txt' ადგილას (დარწმუნდით რომ მთელი ტექსტი ერთ ხაზზეა): ",
    "%1$s changed your password on %2$s." : "%1$s მომხმარებელმა თქვენი პაროლი შეცვალა %2$s-ზე.",
    "Your password on %s was changed." : "თქვენი პაროლი %s-ზე შეიცვალა.",
    "Your password on %s was reset by an administrator." : "თქვენი პაროლი %s-ზე ადმინისტრატორმა აღადგინა.",
    "Password for %1$s changed on %2$s" : "პაროლი %1$s-სთვის შეიცვალა %2$s-ზე",
    "Password changed for %s" : "პაროლი %s-სთვის შეიცვალა",
    "If you did not request this, please contact an administrator." : "თუ ეს არ მოგითხოვიათ, მიმართეთ ადმინისტრატორს",
    "Your email address on %s was changed." : "თქვენი ელ-ფოსტის მისამართი %s-ზე შეიცვალა.",
    "Your email address on %s was changed by an administrator." : "თქვენი ელ-ფოსტის მისამართი %s-ზე ადმინისტრატორმა შეცვალა.",
    "Email address for %1$s changed on %2$s" : "ელ-ფოსტის მისამართი %1$s-სთვის შეიცვალა %2$s-ზე",
    "Email address changed for %s" : "ელ-ფოსტის მისამართი %s-სთვის შეიცვალა",
    "The new email address is %s" : "ახალი ელ-ფოსტის მისამართია %s",
    "Your %s account was created" : "თქვენი %s ანგარიში შექმნილია",
    "Welcome aboard" : "კეთილი იყოს თქვენი ბორტზე მობრძანება",
    "Welcome aboard %s" : "%s, კეთილი იყოს თქვენი ბორტზე მობრძანება",
    "Welcome to your %s account, you can add, protect, and share your data." : "კეთილი იყოს თქვენი %s ანგარიშში მობრძანება, შეგიძლიათ დაამატოთ, დაიცვათ და გააზიაროთ თქვენი მონაცემები.",
    "Your username is: %s" : "თქვენი მომხმარებლის სახელია: %s",
    "Set your password" : "დააყენეთ თქვენი პაროლი",
    "Go to %s" : "გადადით %s-ზე",
    "Install Client" : "დააყენეთ კლიენტი",
    "Logged in user must be a subadmin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ქვე-ადმინისტრატორი",
    "Apps" : "აპლიკაციები",
    "Settings" : "პარამეტრები",
    "Personal" : "პირადი",
    "Administration" : "ადმინისტრაცია",
    "Additional settings" : "დამატებითი პარამეტრები",
    "Overview" : "ზოგადი მიმოხილვა",
    "Basic settings" : "ძირითადი პარამეტრები",
    "Sharing" : "გაზიარება",
    "Personal info" : "პირადი ინფორმაცია",
    "Mobile & desktop" : "მობილური და დესკტოპი",
    "Email server" : "საფოსტო სერვერი",
    "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
    "Background jobs" : "ფონური საქმეები",
    "Create" : "შექმნა",
    "Change" : "შეცვლა",
    "Delete" : "წაშლა",
    "Unlimited" : "ულიმიტო",
    "Verifying" : "მოწმდება",
    "None" : "არც ერთი",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Save changes" : "ცვილებების შენახვა",
    "All" : "ყველა",
    "No results" : "შედეგები არაა",
    "Update to {version}" : "განაახლეთ ვერსიაზე {version}",
    "Remove" : "წაშლა",
    "Disable" : "გამორთვა",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "ეს აპლიკაცია ვერ დაყენდა რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული:",
    "View in store" : "იხილეთ store-ში",
    "Visit website" : "საიტზე სტუმრობა",
    "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
    "User documentation" : "მომხმარებლის დოკუმენტაცია",
    "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
    "Developer documentation" : "დეველოპერის დოკუმენტაცია",
    "Supported" : "მხარდაჭერილია",
    "Featured" : "გამორჩეულები",
    "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
    "Enable all" : "ყველას ამოქმედება",
    "Allow filesystem access" : "ფაილ-სისტემაზე წვდომის მინიჭება",
    "Rename" : "სახელის შეცვლა",
    "Revoke" : "წვდომის გაუქმება",
    "Internet Explorer" : "Internet Explorer-ი",
    "Edge" : "Edge-ი",
    "Firefox" : "Firefox-ი",
    "Google Chrome" : "Google Chrome-ი",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome Android-ისთვის",
    "Sync client - {os}" : "სინქ. კლიენტი - {os}",
    "This session" : "ეს სესია",
    "Device" : "მოწყობილობა",
    "Last activity" : "ბოლო აქტივობა",
    "Web, desktop and mobile clients currently logged in to your account." : "ვებ, დესკტოპ და მობილური კლიენტები ამჟამად ავტორიზირებული თქვენს ანგარიშზე.",
    "Error while creating device token" : "მოწყობილობის ტოკენის ჩატვირთვისას წარმოიქმნა შეცდომა",
    "Error while deleting the token" : "ტოკენის წაშლისას წარმოიქმნა შეცდომა",
    "App name" : "აპლიკაციის სახელი",
    "Create new app password" : "ახალი აპლიკაციის პაროლის შექმნა",
    "Use the credentials below to configure your app or device." : "ქვემოთ მოცემული უფლებამოსილებანის გამოყენება აპლიკაციისა თუ მოწყობილობისთვის.",
    "For security reasons this password will only be shown once." : "უსაფრთხოების მიზნით ეს პაროლი გამოჩნდება მხოლოდ ერთხელ.",
    "Username" : "მომხმარებლის სახელი",
    "Password" : "პაროლი",
    "Done" : "დასრულებულია",
    "Copied!" : "კოპირებულია",
    "Copy" : "კოპირება",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
    "Enable" : "ჩართვა",
    "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
    "Enable server-side encryption" : "სერვერული-მხარის შიფრაციის ამოქმედება",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "შიფრაციის ჩართვის შემდეგ, სერვერზე ატვირთული ყველა ფაილი დაიშიფრება. იმ შემთხვევაში თუ აქტიური შიფრაციის მოდულს აქვს შიფრაციის დეაქტივაციის უნარი და ყველა წინაპირობა დაცულია (მაგ.: აღდგენის გასაღების დაყენება), სხვა დროს შეძლებთ მისი მოქმედების შეჩერებას.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "მხოლოდ შიფრაცია არ იძლევა სისტემის უსაფრთხოების გარანტიას. მეტი ინფორმაციისთვის იმაზე თუ როგორ მუშაობს შიფრაციის აპლიკაცია იხილეთ დოკუმენტაცია და გაეცანით მოხმარების შემთხვევებს.",
    "Be aware that encryption always increases the file size." : "იცოდეთ, შიფრაცია ყოველთვის ზრდის ფაილის ზომას.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "ყოველთვის კარგია თქვენი მონაცემების დაზღვევა, შიფრაციის შემთხვევაში თვენს მონაცემებთან ერთად აუცილებლად დააზღვიეთ შიფრაციის გასაღებებიც.",
    "This is the final warning: Do you really want to enable encryption?" : "ეს ბოლო გაფრთხილებაა: ნამდვილად გსურთ შიფრაციის ამოქმედება?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "შიფრაციის მოდული არაა ჩატვირთული, გთხოვთ აამოქმედოთ ის აპლიკაციის მენიუდან. ",
    "Select default encryption module:" : "აირჩიეთ შიფრაციის საწყისი მოდული:",
    "Current password" : "მიმდინარე პაროლი",
    "New password" : "ახალი პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
    "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
    "Cancel" : "უარყოფა",
    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
    "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
    "Language" : "ენა",
    "Help translate" : "თარგმნის დახმარება",
    "Your phone number" : "თქვენი ტელეფონის ნომერი",
    "Your Twitter handle" : "თქვენი Twitter-is @…",
    "Your website" : "თქვენი ვებ-საიტი",
    "Add" : "დამატება",
    "{size} used" : "მოხმარებულია {size}",
    "Display name" : "დისპლეი სახელი",
    "Email" : "ელ-ფოსტა",
    "Group admin for" : "ადმინისტრატორის შეჯგუფება",
    "Quota" : "ქვოტა",
    "User backend" : "მომხმარებელის ბექენდი",
    "Storage location" : "საცავის ადგილმდებარეობა",
    "Last login" : "ბოლო ავტორიზაცია",
    "Default quota" : "საწყისი კვოტა",
    "Unnamed device" : "უსახელო მოწყობილობა",
    "Your apps" : "თქვენი აპლიკაციები",
    "Disabled apps" : "არამოქმედი აპლიკაციები",
    "Updates" : "განახლებები",
    "App bundles" : "აპლიკაციის შეკვრები",
    "Details" : "დეტალები",
    "Changelog" : "ცვლილებების ლოგი",
    "Add group" : "ჯგუფის დამატება",
    "Active users" : "აქტიური მომხმარებლები",
    "Admins" : "ადმინისტრატორები",
    "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
    "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
    "Send email to new user" : "გაუგზავნეთ ელ-წერილი ახალ მომხმარებელს",
    "Not saved" : "არაა შენახული",
    "Sending…" : "იგზავნება…",
    "Email sent" : "ელ-წერილი გაიგზავნა",
    "Location" : "ადგილმდებარეობა",
    "Profile picture" : "პროფილის სურათი",
    "About" : "შესახებ",
    "Full name" : "სრული სახელი",
    "Phone number" : "ტელეფონის ნომერი",
    "Twitter" : "Twitter-ი",
    "Website" : "ვებ-საიტი",
    "Hide" : "დამალვა",
    "Never" : "არასდროს",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
    "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
    "Documentation" : "დოკუმენტაცია",
    "Forum" : "ფორუმი",
    "Login" : "ლოგინი",
    "Plain" : "ჩვეულებრივი",
    "NT LAN Manager" : "NT LAN მენეჯერი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "ღია დოკუმენტაცია",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
    "Send mode" : "გაგზავნის რეჟიმი",
    "Encryption" : "შიფრაცია",
    "From address" : "მისამართიდან",
    "Authentication method" : "აუტენტიფიკაციის მეთოდი",
    "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "უფლებამოსილებანი",
    "SMTP Username" : "SMTP მოხმარებლის სახელი",
    "SMTP Password" : "SMTP მომხმარებლის პაროლი",
    "Save" : "შენახვა",
    "Send email" : "ელ-წერილის გაგზავნა",
    "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
    "Version" : "ვერსია",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Enforce expiration date" : "ვადის ამოწურვის თარიღის იძულება",
    "Allow public uploads" : "საქვეყნო ატვირთების დაშვება",
    "Always ask for a password" : "ყოველთვის მოხდეს პაროლის მოთხოვნა",
    "Enforce password protection" : "პროლით დაცვის იძულება",
    "Set default expiration date" : "დააყენეთ საწყისი ვადის ამოწურვის თარიღი",
    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
    "Allow sharing with groups" : "ჯგუფებთან გაზიარების მხარდაჭერა",
    "Restrict users to only share with users in their groups" : "შეზღუდეთ მომხმარებლები გააზიარონ მომხმარებლებთან, რომლებიც მიეკუთვნებიან მათ ჯგუფებს",
    "Exclude groups from sharing" : "აკრძალეთ ჯგუფების გაზიარება",
    "These groups will still be able to receive shares, but not to initiate them." : "ეს ჯგუფები ისევ მიიღებენ გაზიარებებს, მაგრამ ვერ წამოიწყებენ მათ.",
    "This text will be shown on the public link upload page when the file list is hidden." : "ეს ტექსტი გამოჩნდება ღია ბმულის ატვირთვის გვერდზე, როდესაც ფაილების სია დამალულია.",
    "Default share permissions" : "საწყისი გაზიარების პარამეტრები",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "განავითარა {communityopen}Nextcloud საზოგადოებამ{linkclose}, {githubopen}კოდი{linkclose} is ლიცენზირებულია {licenseopen}AGPL ლიცენზიით{linkclose}.",
    "Like our Facebook page" : "მოიწონეთ ჩვენი Facebook გვერდი",
    "Follow us on Twitter" : "გამოგვყევით Twitter-ზე",
    "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
    "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები",
    "Migration in progress. Please wait until the migration is finished" : "მიმდინარეობს მიგრაცია. გთხოვთ დაელოდოთ მიგრაციის დასრულებას",
    "Migration started …" : "მიგრაცია დაიწყო …",
    "Select a profile picture" : "აირჩიეთ პროფილის სურათი",
    "Couldn't remove app." : "აპლიკაციის წაშლა ვერ მოხერხდა.",
    "Couldn't update app." : "აპლიკაციის განახლება ვერ მოხერხდა.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "ბექენდს არ აქვს პაროლის ცვლილების მხარდაჭერა, თუმცა მომხმარებლის შიფრაციის გასაღები განახლდა.",
    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
    "All languages" : "ყველა ენა",
    "Everyone" : "ყველა",
    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
    "Please read carefully before activating server-side encryption: " : "სანამ გააქტიურებთ სერვერული-მხარის შიფრაციას გთხოვთ ყურადღებით გაეცნოთ:",
    "Enable encryption" : "შიფრაციის ამოქმედება",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "საჭიროა შიფრაციის გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე. გთხოვთ აამოქმედოთ \"საწყისი მიგრაციის მოდული\" და გაუშვათ 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "საჭიროა შიფრაციის ძველი გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე.",
    "Start migration" : "მიგრაციის დაწყება",
    "Last job execution ran %s. Something seems wrong." : "ბოლო საქმე გაიშვა %s. რაღაც არასწორია.",
    "Last job ran %s." : "ბოლო საქმის გაშვება - %s.",
    "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php უნდა გაუშვას სისტემურმა მოხმარებელმა \"%s\".",
    "days" : "დღე",
    "Upload new" : "ახალი ატვირთვა",
    "Select from Files" : "აირჩიეთ ფაილებიდან",
    "Remove image" : "სურათის წაშლა",
    "Choose as profile picture" : "აირჩიეთ პროფილის სურათად",
    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
    "Address" : "მისამართი",
    "Your postal address" : "თქვენი საფოსტო მისამართი",
    "It can take up to 24 hours before the account is displayed as verified." : "თქვენი ანგარიშის ვერიფიცირებულად გამოჩენამ შეიძლება გასტანოს 24 საათი.",
    "Link https://…" : "ბმული https://…",
    "Twitter handle @…" : "Twitter @…",
    "Avatar" : "ავატარი"
},
"nplurals=2; plural=(n!=1);");
